@@ -80,6 +80,18 @@ sub as_string {
     return $string;
 }
 
+sub update_headers {
+    my ($self)  = @_;
+    my $proplen = $self->property_length();
+    my $textlen = $self->text_length();
+
+    $self->set_header( 'Text-content-length' => $textlen )
+        if defined $self->get_text_block();
+    $self->set_header( 'Prop-content-length', $proplen )
+        if $proplen;
+    $self->set_header( 'Content-length' => $proplen + $textlen );
+}
+
 # access methods to the inner blocks
 sub set_header {
     my ($self, $h, $v) = @_;
@@ -98,9 +110,7 @@ sub set_property {
     my $prop = $self->get_property_block()
       || $self->set_property_block( SVN::Dump::Property->new() );
     $prop->set( $k, $v );
-    my $l = length( $prop->as_string() );
-    $self->set_header( 'Prop-content-length', $l );
-    $self->set_header( 'Content-length' => $l + $self->text_length() );
+    $self->update_headers();
     return $v;
 }
 
@@ -109,15 +119,23 @@ sub get_property {
     return $self->get_property_block()->get($k);
 }
 
+sub delete_property {
+    my ( $self, @keys ) = @_;
+    my $prop = $self->get_property_block()
+        || $self->set_property_block( SVN::Dump::Property->new() );
+    my @result = $prop->delete(@keys);
+    $self->update_headers();
+    return wantarray ? @result : pop @result; # behave like delete()
+}
+
 sub set_text {
     my ($self, $t) = @_;
     my $text_block = $self->get_text_block()
       || $self->set_text_block( SVN::Dump::Text->new() );
 
     $text_block->set( $t );
-    $self->set_header( 'Text-content-length' => length( $t ) );
-    $self->set_header(
-        'Content-length' => length($t) + $self->property_length() );
+    $self->update_headers();
+    return $t;
 }
 
 sub get_text {
@@ -136,7 +154,7 @@ SVN::Dump::Record - A SVN dump record
 
 =head1 SYNOPSIS
 
-    # SVN::Dump::Record objects are returns by the next_record()
+    # SVN::Dump::Record objects are returned by the next_record()
     # method of SVN::Dump
 
 =head1 DESCRIPTION
@@ -177,6 +195,10 @@ Set the property C<$p> to the value C<$v>.
 
 Get the value of property C<$p>.
 
+=item delete_property( @k )
+
+Delete the
+
 =item set_text( $t )
 
 Set the value of the text block.
@@ -210,6 +232,10 @@ headers.
 Get or set the C<SVN::Dump::Property> object that represents the record
 property block.
 
+=item delete_property( @keys )
+
+Delete the given properties. Behave like the builtin C<delete()>.
+
 =item set_text_block( $text )
 
 =item get_text_block()
@@ -248,6 +274,13 @@ like this:
 Note that there is a single blank line after the first header block,
 and four after the included one.
 
+=item update_headers()
+
+Update the various C<...-length> headers. Used internally.
+
+B<You must call this method if you update the inner property or text
+blocks directly, or the results of C<as_string()> will be inconsistent.>
+
 =back
 
 =head2 Information methods
@@ -311,9 +344,11 @@ any modification of the record.
 
 C<SVN::Dump::Headers>, C<SVN::Dump::Property>, C<SVN::Dump::Text>.
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT
 
-Copyright 2006 Philippe 'BooK' Bruhat, All Rights Reserved.
+Copyright 2006-2011 Philippe 'BooK' Bruhat, All Rights Reserved.
+
+=head1 LICENSE
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
